@@ -50,8 +50,9 @@ make_tmp_dir() {
     if mkdir -m 0755 "$tmp"'/'"$prefix$serial" >/dev/null 2>&1; then
       loop='no'
     else
-      serial=$(($serial + 1))
-      if [ "$(($serial % 200))" = '0' ]; then
+      serial=`expr $serial + 1`
+      serial_mod=`expr $serial % 200`
+      if [ "$serial_mod" = '0' ]; then
         echo 'Warning: The "'"$tmp"'" directory may be under attack.'
         echo
       fi
